@@ -26,3 +26,12 @@ from ._torchvision import torchvision
 
 ### tensorboard
 from ._tensorboard import tensorboard
+
+### dask
+from ._dask import dask
+
+### pyarrow
+from .pyarrow import pyarrow
+
+### bokeh
+from .bokeh import bokeh
