@@ -3,7 +3,7 @@ def dask():
     from packaging.version import parse
     from importlib import import_module
 
-    from ../_install_min import install_min
+    from .._install_min import install_min
 
     install_min(package="dask", pip_name="dask[complete]", version="2021.4.0")
 
